
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    require Test::More;
    Test::More::plan(skip_all => 'these tests are for testing by the author');
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007000
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
SubmittingPatches
dzil
OurPkgVersion
ini
executables
Caleb
Cushing
xenoterracide
Grahan
Ollis
plicease
Alexandr
Ciornii
alexchorny
Alexei
Znamensky
russoz
Christian
Walde
walde
Christopher
Madsen
perl
David
Golden
dagolden
Graham
lib
Dist
Zilla
Plugin
